#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "Tempo expirado"
#define MSG_CAPABILITIES "No foi possvel trocar capacidades"
#define MSG_CLIENT_CLOSED_CNX "Cliente encerrou a conexo"
#define MSG_CLIENT_READ_ERR "Erro de leitura do cliente"
#define MSG_CANT_OPEN_CNX "No foi possvel abrir conexo"
#define MSG_CANT_CREATE_DATA_SOCKET "No foi possvel criar socket de dados"
#define MSG_DEBUG_CLIENT_IS "Endereo do cliente "
#define MSG_SYNTAX_ERROR_IP "Erro de sintaxe no endereo IP"
#define MSG_PORT_SUCCESSFUL "Comando PORT bem sucedido"
#define MSG_ONLY_IPV4V6 "Somente IPv4 e IPv6 so suportados (1,2)"
#define MSG_ONLY_IPV4 "Somente IPv4  suportado (1)"
#define MSG_TIMEOUT_PARSER "Tempo expirado - experimente digitar um pouco mais rpido na prxima vez"
#define MSG_LINE_TOO_LONG "Linha muito comprida"
#define MSG_LOG_OVERFLOW "O cliente tentou estourar o buffer da linha de comando"
#define MSG_GOODBYE "Adeus. Voc enviou %llu e recebeu %llu kbytes."
#define MSG_DEBUG_COMMAND "Comando"
#define MSG_IS_YOUR_CURRENT_LOCATION " a sua localizao atual"
#define MSG_NOT_LOGGED_IN "Voc no est logado"
#define MSG_AUTH_UNIMPLEMENTED "Extenses de segurana no implementadas"
#define MSG_NO_FILE_NAME "Nome do arquivo no informado"
#define MSG_NO_DIRECTORY_NAME "Nome do diretrio no informado"
#define MSG_NO_RESTART_POINT "No existe um ponto de reincio"
#define MSG_ABOR_SUCCESS "Comando ABOR bem sucedido"
#define MSG_MISSING_ARG "Falta argumento"
#define MSG_GARBAGE_FOUND "Sujeira encontrada depois do valor"
#define MSG_VALUE_TOO_LARGE "Valor muito grande"
#define MSG_IDLE_TIME "Tempo ocioso configurado para %lu segundos"
#define MSG_SITE_HELP "Os seguintes comandos SITE so reconhecidos"
#define MSG_BAD_CHMOD "Permisses invlidas"
#define MSG_UNKNOWN_EXTENSION " uma extenso desconhecida"
#define MSG_XDBG_OK "Comando XDBG foi bem sucedido, nvel de depurao agora  %d"
#define MSG_UNKNOWN_COMMAND "Comando desconhecido"
#define MSG_TIMEOUT_NOOP "Tempo expirado (nenhuma operao durante %lu segundos)"
#define MSG_TIMEOUT_DATA "Tempo expirado (nenhum dado novo durante %lu segundos)"
#define MSG_SLEEPING "Zzz..."
#define MSG_ALREADY_LOGGED "Voc j est logado"
#define MSG_ANY_PASSWORD "Qualquer senha funcionar"
#define MSG_ANONYMOUS_LOGGED "Usurio annimo logado"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL "Usurio annimo logado no FTP virtual"
#define MSG_USER_OK "Usurio %s OK. Senha requerida"
#define MSG_CANT_DO_TWICE "No  possvel realizar isto na sesso atual"
#define MSG_UNABLE_SECURE_ANON "No  possvel configurar FTP annimo seguro"
#define MSG_BANDWIDTH_RESTRICTED "Seu uso de largura de banda est restrito"
#define MSG_NO_PASSWORD_NEEDED "Senha no requerida"
#define MSG_NOTRUST "Desculpe, no posso confiar em voc"
#define MSG_WHOAREYOU "Por favor informe quem voc "
#define MSG_AUTH_FAILED "Autenticao falhou, desculpe"
#define MSG_AUTH_TOOMANY "Muitas falhas de autenticao"
#define MSG_NO_HOMEDIR "Diretrio pessoal no disponvel - cancelando"
#define MSG_NO_HOMEDIR2 "%s no existe ou  inalcanvel"
#define MSG_START_SLASH "Iniciando em /"
#define MSG_USER_GROUP_ACCESS "Usurio %s tem acesso de grupo a"
#define MSG_FXP_SUPPORT "Este servidor suporta transferncia FXP"
#define MSG_RATIO "A proporo %u:%u (UL/DL) deve ser respeitada"
#define MSG_CHROOT_FAILED "No foi possvel configurar uma jaula chroot() segura"
#define MSG_CURRENT_DIR_IS "OK. Diretrio atual  %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "OK. Diretrio restrito atual  %s"
#define MSG_IS_NOW_LOGGED_IN "%s agora est logado"
#define MSG_CANT_CHANGE_DIR "No foi possvel entrar no diretrio %s"
#define MSG_PATH_TOO_LONG "Path muito comprido"
#define MSG_CANT_PASV "No  possvel usar PASV em conexes IPv6 (comando obsoleto). Use o comando EPSV."
#define MSG_CANT_PASSIVE "No foi possvel abrir uma conexo passiva"
#define MSG_PORTS_BUSY "Todas as portas TCP reservadas esto ocupadas"
#define MSG_GETSOCKNAME_DATA "No foi possvel identificar o socket de dados local"
#define MSG_GETPEERNAME "No foi possvel identificar o socket local"
#define MSG_INVALID_IP "Desculpe, endereo fornecido invlido"
#define MSG_NO_EPSV "Favor utilizar um cliente compatvel com IPv6, com suporte a EPSV"
#define MSG_BAD_PORT "Desculpe, no me conectarei a portas < 1024"
#define MSG_NO_FXP "No abrirei uma conexo para %s (somente para %s)"
#define MSG_FXP "Transferncia FXP : de %s para %s"
#define MSG_NO_DATA_CONN "No existe conexo de dados"
#define MSG_ACCEPT_FAILED "A conexo no pde ser aceita"
#define MSG_ACCEPT_SUCCESS "Conexo de dados aceita"
#define MSG_CNX_PORT_FAILED "No foi possvel abrir conexo de dados com a porta %d"
#define MSG_CNX_PORT "Conectando com a porta %d"
#define MSG_ANON_CANT_MKD "Desculpe, usurios annimos no tm permisso para criar diretrios"
#define MSG_ANON_CANT_RMD "Desculpe, usurios annimos no tm permisso para remover diretrios"
#define MSG_ANON_CANT_RENAME "Usurios annimos no tm permisso para mover/renomear arquivos"
#define MSG_ANON_CANT_CHANGE_PERMS "Usurios annimos no podem alterar permisses"
#define MSG_GLOB_NO_MEMORY "Sem memria (devido expanso de %s)"
#define MSG_PROBABLY_DENIED "(Isto provavelmente significa \"Permisso negada\")"
#define MSG_GLOB_READ_ERROR "Erro de leitura durante expanso de %s"
#define MSG_GLOB_NO_MATCH "Nenhuma ocorrncia de %s em %s"
#define MSG_CHMOD_FAILED "No foi possvel alterar permisses em %s"
#define MSG_CHMOD_SUCCESS "Permisses alteradas em %s"
#define MSG_CHMOD_TOTAL_FAILURE "Desculpe, no foi possvel alterar nenhuma permisso"
#define MSG_ANON_CANT_DELETE "Usurios annimos no tm permisso para remover arquivos"
#define MSG_ANON_CANT_OVERWRITE "Usurios annimos no tm permisso para sobrescrever arquivos existentes"
#define MSG_DELE_FAILED "No foi possvel remover %s"
#define MSG_DELE_SUCCESS "%s%s%s%s foi removido"
#define MSG_DELE_TOTAL_FAILURE "Nenhum arquivo foi removido"
#define MSG_LOAD_TOO_HIGH \
    "A carga era %3.2f quando a conexo foi realizada. No  permitido recebimento\n" \
    "de arquivos por usurios annimos quando a carga estiver to alta.\n" \
    "Envio de arquivos  sempre permitido."
#define MSG_OPEN_FAILURE "No foi possvel abrir %s"
#define MSG_OPEN_FAILURE2 "No foi possvel abrir esse arquivo"
#define MSG_STAT_FAILURE "No foi possvel determinar o tamanho do arquivo"
#define MSG_STAT_FAILURE2 "No foi possvel verificar a existncia do arquivo"
#define MSG_REST_TOO_LARGE_FOR_FILE "Restart offset %lld  muito grande para tamanho de arquivo %lld."
#define MSG_REST_RESET "Restart offset reinicializado em 0"
#define MSG_NOT_REGULAR_FILE "Somente arquivos comuns podem ser recebidos"
#define MSG_NOT_MODERATED \
    "Este arquivo foi enviado por um usurio annimo. Porm ainda no\n" \
    "foi aprovado pelos administradores do site para poder ser recebido."
#define MSG_RATIO_DENIAL \
    "Desculpe, a proporo de envio/recebimento  %u:%u .\n" \
    "At o momento voc enviou %llu Kb e recebeu %llu Kb.\n" \
    "Por favor envie mais arquivos e tente fazer o recebimento posteriormente."
#define MSG_NO_MORE_TO_DOWNLOAD "No h mais nada para receber"
#define MSG_WINNER "O computador  seu amigo. Confie nele"
#define MSG_KBYTES_LEFT "%.1f kbytes para receber"
#define MSG_ABORTED "Transferncia cancelada"
#define MSG_DATA_WRITE_FAILED "Erro durante escrita  conexo de dados"
#define MSG_DATA_READ_FAILED "Erro durante leitura da conexo de dados"
#define MSG_MMAP_FAILED "No foi possvel mapear o arquivo na memria"
#define MSG_WRITE_FAILED "Erro durante escrita a arquivo"
#define MSG_TRANSFER_RATE_M "%.3f segundos (medidos aqui), %.2f Mbytes por segundo"
#define MSG_TRANSFER_RATE_K "%.3f segundos (medidos aqui), %.2f Kbytes por segundo"
#define MSG_TRANSFER_RATE_B "%.3f segundos (medidos aqui), %.2f bytes por segundo"
#define MSG_SPACE_FREE_M "%.1f Mbytes de espao livre em disco"
#define MSG_SPACE_FREE_K "%f Kbytes de espao livre em disco"
#define MSG_DOWNLOADED "recebido"
#define MSG_REST_NOT_NUMERIC "REST requer um parmetro numrico"
#define MSG_REST_ASCII_STRICT "Marca de resposta deve ser 0 no modo ASCII"
#define MSG_REST_ASCII_WORKAROUND "Reiniciando em %lld. Porm estamos no modo ASCII"
#define MSG_REST_SUCCESS "Reiniciando em %lld"
#define MSG_SANITY_DIRECTORY_FAILURE "Nome de diretrio proibido"
#define MSG_SANITY_FILE_FAILURE "Nome de arquivo proibido: %s"
#define MSG_MKD_FAILURE "No foi possvel criar diretrio"
#define MSG_MKD_SUCCESS "O diretrio foi criado com sucesso"
#define MSG_RMD_FAILURE "No foi possvel remover diretrio"
#define MSG_RMD_SUCCESS "O diretrio foi removido com sucesso"
#define MSG_TIMESTAMP_FAILURE "No foi possvel obter uma marca de tempo"
#define MSG_MODE_ERROR "Somente modos ASCII e binrio so suportados"
#define MSG_CREATE_FAILURE "No foi possvel criar arquivo"
#define MSG_ABRT_ONLY "ABRT  o nico comando vlido durante transmisso"
#define MSG_UPLOAD_PARTIAL "parcialmente enviado"
#define MSG_REMOVED "removido"
#define MSG_UPLOADED "enviado"
#define MSG_GMTIME_FAILURE "No foi possvel obter a hora local"
#define MSG_TYPE_8BIT_FAILURE "Somente bytes de 8 bits so suportados. No estamos h 10 anos atrs"
#define MSG_TYPE_UNKNOWN "TYPE desconhecido"
#define MSG_TYPE_SUCCESS "TYPE agora "
#define MSG_STRU_FAILURE "Somente File (arquivo)  suportado"
#define MSG_MODE_FAILURE "Utilize modo Stream (fluxo)"
#define MSG_RENAME_ABORT "Cancelando comando de renomeao anterior"
#define MSG_RENAME_RNFR_SUCCESS "RNFR aceito - arquivo existe, pronto para destino"
#define MSG_FILE_DOESNT_EXIST "Desculpe, esse arquivo no existe"
#define MSG_RENAME_ALREADY_THERE "RENAME falhou - arquivo de destino j existe"
#define MSG_RENAME_NORNFR " necessrio RNFR antes de RNTO"
#define MSG_RENAME_FAILURE "Falha em renomear/mover"
#define MSG_RENAME_SUCCESS "Arquivo renomeado ou movido com sucesso"
#define MSG_NO_SUPERSERVER "Por favor execute pure-ftpd dentro de um super-servidor (como tcpserver)"
#define MSG_NO_FTP_ACCOUNT "No foi possvel encontrar a conta 'ftp'"
#define MSG_CONF_ERR "Erro de configurao"
#define MSG_NO_VIRTUAL_FILE "Est faltando arquivo de usurios virtuais"
#define MSG_ILLEGAL_THROTTLING "Valor ilegal para limite de transferncia"
#define MSG_ILLEGAL_TRUSTED_GID "GID de confiana para chroot ilegal"
#define MSG_ILLEGAL_USER_LIMIT "Limite de usurio ilegal"
#define MSG_ILLEGAL_FACILITY "Nome de facilidade desconhecido"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "Arquivo de configurao de LDAP invlido"
#define MSG_ILLEGAL_LOAD_LIMIT "Limite de carga ilegal"
#define MSG_ILLEGAL_PORTS_RANGE "Faixa de portas ilegal"
#define MSG_ILLEGAL_LS_LIMITS "Limite de 'ls' ilegal"
#define MSG_ILLEGAL_FORCE_PASSIVE "IP forado para conexes passivas ilegal"
#define MSG_ILLEGAL_RATIO "Proporo de envio/recebimento ilegal"
#define MSG_ILLEGAL_UID_LIMIT "Limite de uid ilegal"
#define MSG_ILLEGAL_OPTION "Opo de execuo desconhecida"
#define MSG_LDAP_MISSING_BASE "Est faltando LDAPBaseDN no arquivo de configurao LDAP"
#define MSG_LDAP_WRONG_PARMS "Parmetros LDAP incorretos"
#define MSG_NEW_CONNECTION "Nova conexo a partir de %s"
#define MSG_WELCOME_TO "Bem-vindo a"
#define MSG_MAX_USERS "%lu usurios (o mximo) j esto conectados, desculpe"
#define MSG_NB_USERS "Voc  o usurio nmero %u de %u permitidos"
#define MSG_WELCOME_TIME "Hora local agora  %02d:%02d. Porta do servidor: %u."
#define MSG_ANONYMOUS_FTP_ONLY "Somente FTP annimo  permitido aqui"
#define MSG_RATIOS_EVERYONE "PROPORES ESTO HABILITADAS PARA TODOS :"
#define MSG_RATIOS_ANONYMOUS "USURIOS ANNIMOS ESTO SUJEITOS A UMA PROPORO DE UL/DL :"
#define MSG_RATIOS_RULE "para receber %u Mb,  obrigatrio enviar %u Mb de arquivos."
#define MSG_INFO_IDLE_M "Voc ser desconectado aps %lu minutos de inatividade."
#define MSG_INFO_IDLE_S "Voc ser desconectado aps %lu segundos de inatividade."
#define MSG_CANT_READ_FILE "Desculpe, no foi possvel ler [%s]"
#define MSG_LS_TRUNCATED "Resultado truncado em %u ocorrncias"
#define MSG_LS_SUCCESS "%u ocorrncias no total"
#define MSG_LOGOUT "Fim de sesso."
#define MSG_AUTH_FAILED_LOG "Autenticao falhou para usurio [%s]"
#define MSG_ILLEGAL_UMASK "Umask invlida"
#define MSG_STANDALONE_FAILED "No foi possvel iniciar um servidor independente"
#define MSG_NO_ANONYMOUS_LOGIN "Este  um sistema privado - No  permitido usurio annimo"
#define MSG_ANONYMOUS_ANY_PASSWORD "Qualquer senha funcionar"
#define MSG_MAX_USERS_IP "Conexes demais (%lu) a partir deste IP"
#define MSG_ACTIVE_DISABLED "Modo ativo est desabilitado"
#define MSG_TRANSFER_SUCCESSFUL "Arquivo transferido com sucesso"
#define MSG_NO_DISK_SPACE "Disco cheio - por favor envie arquivo mais tarde"
#define MSG_OUT_OF_MEMORY "Sem memria"
#define MSG_ILLEGAL_TRUSTED_IP "Endereo IP de confiana ilegal"
#define MSG_NO_ASCII_RESUME "Reiniciar em modo ASCII  inseguro, por favor remova o arquivo antes"
#define MSG_UNKNOWN_ALTLOG "Formato de log desconhecido"
#define MSG_ACCOUNT_DISABLED "No  possvel conectar como [%s] : conta desabilitada"
#define MSG_SQL_WRONG_PARMS "Parmetros SQL incorretos"
#define MSG_ILLEGAL_CONFIG_FILE_SQL "Arquivo de configurao SQL invlido"
#define MSG_SQL_MISSING_SERVER "Est faltando o servidor no arquivo de configurao SQL"
#define MSG_SQL_DOWN "O servidor SQL aparenta estar fora de operao"
#define MSG_ILLEGAL_QUOTA "Cota invlida"
#define MSG_QUOTA_FILES "%llu arquivos usados (%d%%) - autorizado: %llu arquivos"
#define MSG_QUOTA_SIZE "%llu Kbytes usados (%d%%) - autorizado: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Cota excedida : [%s] no ser armazenado"
#define MSG_AUTH_UNKNOWN "Mtodo de autenticao desconhecido"
#define MSG_PDB_BROKEN "No foi possvel ler o arquivo indexado do puredb (ou um formato antigo foi detectado) - Experimente pure-pw mkdb"
#define MSG_ALIASES_ALIAS "%s  um apelido para %s."
#define MSG_ALIASES_UNKNOWN "Apelido %s desconhecido."
#define MSG_ALIASES_BROKEN_FILE "Arquivo de apelidos danificado"
#define MSG_ALIASES_LIST "Os seguintes apelidos esto disponveis :"
#define MSG_PERUSER_MAX "No posso aceitar mais do que %lu conexes do mesmo usurio"
#define MSG_IPV6_OK "Conexes IPv6 tambm so bem-vindas neste servidor"
#define MSG_TLS_INFO "TLS: Habilitado %s com %s, criptografia de %d bits"
#define MSG_TLS_WEAK "TLS: Criptografia muito fraca"
#define MSG_TLS_NEEDED "Desculpe, sesses sem criptografia no so aceitas neste servidor.\n" \
    "Por favor reconecte-se usando mecanismos de segurana TLS."
#define MSG_ILLEGAL_CHARSET "Conjunto de caracteres ilegal"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"
